@@ -21,16 +21,16 @@
 #' # Or add to plot as annotation
 #' image <- image_fill(logo, 'none')
 #' raster <- as.raster(image)
-#' myplot <- qplot(mpg, wt, data = mtcars)
+#' myplot <- ggplot(mtcars, aes(mpg, wt)) + geom_point()
 #' myplot + annotation_raster(raster, 25, 35, 3, 5)
 #'
 #' # Or overplot image using grid
 #' library(grid)
-#' qplot(speed, dist, data = cars, geom = c("point", "smooth"))
+#' ggplot(cars, aes(speed, dist)) + geom_point() + geom_smooth()
 #' grid.raster(image)
 image_ggplot <- function(image, interpolate = FALSE) {
   info <- image_info(image)
-  ggplot2::ggplot(data.frame(x = 0, y = 0), ggplot2::aes_string('x', 'y')) +
+  ggplot2::ggplot() +
     ggplot2::geom_blank() +
     ggplot2::theme_void() +
     ggplot2::coord_fixed(expand = FALSE, xlim = c(0, info$width), ylim = c(0, info$height)) +
